#ifndef _timed_circle_h
#define _timed_circle_h

class Timed_Circle : public Circle
{
public:

	int create(unsigned int size);
	int insert(struct logbits lb);
	int walk(struct logbits **lb);

	void updatestats(void);
	time_t oldest(void);

	long long getreqcount(void) { return reqcount; }
	long long getbytecount(void) { return bytecount; }
	long long getsummary(int r_c) { return rc_summary[r_c]; }

private:
	int clearbuckets(const unsigned int from, const unsigned int to);
	void resetbucketstats(const unsigned int r);

	void garbagecollection(void);

	long long reqcount, bytecount;
	long long rc_summary[6];

	unsigned int bucketsize; /* how many buckets (seconds) ? */
	unsigned int bucketpos; /* which bucket are we using now? */

	/* store hits for a given second in here.
	 * some bits of the logbits struct aren't used in the circle but
	 * it's better than making an entirely new struct */
	typedef struct logbits HIT;

	/* the timed_circle_struct is a set of buckets; each bucket contains
	 * data about hits for a given second. Each hit is stored in a
	 * HIT array inside the relevant bucket */
	struct timed_circle_struct
	{
		time_t time; /* second this bucket represents */

		/* stats for the HITs array */
		long long reqcount, bytecount;
		long long rc_summary[6];

		unsigned int hitsize; /* how big is the array for hits? */
		unsigned int hitpos; /* how far along hits array we are */
		HIT *hits; /* hits for this second go into array */

	} *tab;

	/* for walk() */
	unsigned int walk_bucketpos;
	unsigned int walk_hitpos;

};

#endif
